@@ -12,16 +12,21 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+# isort:off
+from keras_cv import version_check
+
+version_check.check_tf_version()
+# isort:on
+
+from keras_cv import datasets
 from keras_cv import layers
+from keras_cv import losses
 from keras_cv import metrics
 from keras_cv import models
 from keras_cv import utils
-from keras_cv import version_check
 from keras_cv.core import ConstantFactorSampler
 from keras_cv.core import FactorSampler
 from keras_cv.core import NormalFactorSampler
 from keras_cv.core import UniformFactorSampler
 
-version_check.check_tf_version()
-
-__version__ = "0.2.9"
+__version__ = "0.3.1"
