@@ -77,6 +77,9 @@ class ChannelShuffle(BaseImageAugmentationLayer):
 
         return image
 
+    def augment_bounding_boxes(self, bounding_boxes, **kwargs):
+        return bounding_boxes
+
     def augment_label(self, label, transformation=None, **kwargs):
         return label
 
