@@ -17,83 +17,126 @@ import tensorflow as tf
 from absl.testing import parameterized
 
 from keras_cv import core
-from keras_cv.layers import object_detection
-from keras_cv.layers import preprocessing
-from keras_cv.layers import regularization
+from keras_cv import layers as cv_layers
 
 
-def custom_compare(obj1, obj2):
-    if isinstance(obj1, (core.FactorSampler, tf.keras.layers.Layer)):
+def exhaustive_compare(obj1, obj2):
+    classes_supporting_get_config = (
+        core.FactorSampler,
+        tf.keras.layers.Layer,
+        cv_layers.BaseImageAugmentationLayer,
+    )
+
+    # If both objects are either one of list or tuple then their individual
+    # elements also must be checked exhaustively.
+    if isinstance(obj1, (list, tuple)) and isinstance(obj2, (list, tuple)):
+        # Length based checks.
+        if len(obj1) == 0 and len(obj2) == 0:
+            return True
+        if len(obj1) != len(obj2):
+            return False
+
+        # Exhaustive check for all elements.
+        for v1, v2 in list(zip(obj1, obj2)):
+            return exhaustive_compare(v1, v2)
+
+    # If the objects are dicts then we simply call the `config_equals` function
+    # which supports dicts.
+    elif isinstance(obj1, (dict)) and isinstance(obj2, (dict)):
+        return config_equals(v1, v2)
+
+    # If both objects are subclasses of Keras classes that support `get_config`
+    # method, then we compare their individual attributes using `config_equals`.
+    elif isinstance(obj1, classes_supporting_get_config) and isinstance(
+        obj2, classes_supporting_get_config
+    ):
         return config_equals(obj1.get_config(), obj2.get_config())
-    elif inspect.isfunction(obj1):
+
+    # Following checks are if either of the objects are _functions_, not methods
+    # or callables, since Layers and other unforeseen objects may also fit into
+    # this category. Specifically for Keras activation functions.
+    elif inspect.isfunction(obj1) and inspect.isfunction(obj2):
+        return tf.keras.utils.serialize_keras_object(
+            obj1
+        ) == tf.keras.utils.serialize_keras_object(obj2)
+    elif inspect.isfunction(obj1) and not inspect.isfunction(obj2):
         return tf.keras.utils.serialize_keras_object(obj1) == obj2
-    elif inspect.isfunction(obj2):
+    elif inspect.isfunction(obj2) and not inspect.isfunction(obj1):
         return obj1 == tf.keras.utils.serialize_keras_object(obj2)
+
+    # Lastly check for primitive datatypes and objects that don't need
+    # additional preprocessing.
     else:
         return obj1 == obj2
 
 
 def config_equals(config1, config2):
-    for key in list(config1.keys()) + list(config2.keys()):
+    # Both `config1` and `config2` are python dicts. So the first check is to
+    # see if both of them have same keys.
+    if config1.keys() != config2.keys():
+        return False
+
+    # Iterate over all keys of the configs and compare each entry exhaustively.
+    for key in list(config1.keys()):
         v1, v2 = config1[key], config2[key]
-        if not custom_compare(v1, v2):
+        if not exhaustive_compare(v1, v2):
             return False
     return True
 
 
 class SerializationTest(tf.test.TestCase, parameterized.TestCase):
     @parameterized.named_parameters(
-        ("AutoContrast", preprocessing.AutoContrast, {"value_range": (0, 255)}),
-        ("ChannelShuffle", preprocessing.ChannelShuffle, {"seed": 1}),
-        ("CutMix", preprocessing.CutMix, {"seed": 1}),
-        ("Equalization", preprocessing.Equalization, {"value_range": (0, 255)}),
-        ("Grayscale", preprocessing.Grayscale, {}),
-        ("GridMask", preprocessing.GridMask, {"seed": 1}),
-        ("MixUp", preprocessing.MixUp, {"seed": 1}),
+        ("AutoContrast", cv_layers.AutoContrast, {"value_range": (0, 255)}),
+        ("ChannelShuffle", cv_layers.ChannelShuffle, {"seed": 1}),
+        ("CutMix", cv_layers.CutMix, {"seed": 1}),
+        ("Equalization", cv_layers.Equalization, {"value_range": (0, 255)}),
+        ("Grayscale", cv_layers.Grayscale, {}),
+        ("GridMask", cv_layers.GridMask, {"seed": 1}),
+        ("MixUp", cv_layers.MixUp, {"seed": 1}),
         (
             "RandomChannelShift",
-            preprocessing.RandomChannelShift,
+            cv_layers.RandomChannelShift,
             {"value_range": (0, 255), "factor": 0.5},
         ),
         (
             "Posterization",
-            preprocessing.Posterization,
+            cv_layers.Posterization,
             {"bits": 3, "value_range": (0, 255)},
         ),
         (
             "RandomColorDegeneration",
-            preprocessing.RandomColorDegeneration,
+            cv_layers.RandomColorDegeneration,
             {"factor": 0.5, "seed": 1},
         ),
         (
             "RandomCutout",
-            preprocessing.RandomCutout,
+            cv_layers.RandomCutout,
             {"height_factor": 0.2, "width_factor": 0.2, "seed": 1},
         ),
         (
             "RandomHue",
-            preprocessing.RandomHue,
+            cv_layers.RandomHue,
             {"factor": 0.5, "value_range": (0, 255), "seed": 1},
         ),
         (
             "RandomSaturation",
-            preprocessing.RandomSaturation,
+            cv_layers.RandomSaturation,
             {"factor": 0.5, "seed": 1},
         ),
         (
             "RandomSharpness",
-            preprocessing.RandomSharpness,
+            cv_layers.RandomSharpness,
             {"factor": 0.5, "value_range": (0, 255), "seed": 1},
         ),
         (
             "RandomShear",
-            preprocessing.RandomShear,
+            cv_layers.RandomShear,
             {"x_factor": 0.3, "x_factor": 0.3, "seed": 1},
         ),
-        ("Solarization", preprocessing.Solarization, {"value_range": (0, 255)}),
+        ("Solarization", cv_layers.Solarization, {"value_range": (0, 255)}),
         (
             "RandAugment",
-            preprocessing.RandAugment,
+            cv_layers.RandAugment,
             {
                 "value_range": (0, 255),
                 "magnitude": 0.5,
@@ -104,17 +147,24 @@ class SerializationTest(tf.test.TestCase, parameterized.TestCase):
         ),
         (
             "RandomAugmentationPipeline",
-            preprocessing.RandomAugmentationPipeline,
-            {"layers": [], "augmentations_per_image": 1, "rate": 1.0},
+            cv_layers.RandomAugmentationPipeline,
+            {
+                "layers": [
+                    cv_layers.RandomSaturation(factor=0.5),
+                    cv_layers.RandomColorDegeneration(factor=0.5),
+                ],
+                "augmentations_per_image": 1,
+                "rate": 1.0,
+            },
         ),
         (
             "RandomChoice",
-            preprocessing.RandomChoice,
+            cv_layers.RandomChoice,
             {"layers": [], "seed": 3, "auto_vectorize": False},
         ),
         (
             "RandomColorJitter",
-            preprocessing.RandomColorJitter,
+            cv_layers.RandomColorJitter,
             {
                 "value_range": (0, 255),
                 "brightness_factor": (-0.2, 0.5),
@@ -126,7 +176,7 @@ class SerializationTest(tf.test.TestCase, parameterized.TestCase):
         ),
         (
             "RandomResizedCrop",
-            preprocessing.RandomResizedCrop,
+            cv_layers.RandomResizedCrop,
             {
                 "target_size": (224, 224),
                 "crop_area_factor": (0.08, 1.0),
@@ -137,17 +187,17 @@ class SerializationTest(tf.test.TestCase, parameterized.TestCase):
         ),
         (
             "DropBlock2D",
-            regularization.DropBlock2D,
+            cv_layers.DropBlock2D,
             {"rate": 0.1, "block_size": (7, 7), "seed": 1234},
         ),
         (
             "StochasticDepth",
-            regularization.StochasticDepth,
+            cv_layers.StochasticDepth,
             {"rate": 0.1},
         ),
         (
             "SqueezeAndExcite2D",
-            regularization.SqueezeAndExcite2D,
+            cv_layers.SqueezeAndExcite2D,
             {
                 "filters": 16,
                 "ratio": 0.25,
@@ -157,14 +207,14 @@ class SerializationTest(tf.test.TestCase, parameterized.TestCase):
         ),
         (
             "DropPath",
-            regularization.DropPath,
+            cv_layers.DropPath,
             {
                 "rate": 0.2,
             },
         ),
         (
             "MaybeApply",
-            preprocessing.MaybeApply,
+            cv_layers.MaybeApply,
             {
                 "rate": 0.5,
                 "layer": None,
@@ -173,12 +223,12 @@ class SerializationTest(tf.test.TestCase, parameterized.TestCase):
         ),
         (
             "RandomJpegQuality",
-            preprocessing.RandomJpegQuality,
+            cv_layers.RandomJpegQuality,
             {"factor": (75, 100)},
         ),
         (
             "AugMix",
-            preprocessing.AugMix,
+            cv_layers.AugMix,
             {
                 "value_range": (0, 255),
                 "severity": 0.3,
@@ -190,9 +240,9 @@ class SerializationTest(tf.test.TestCase, parameterized.TestCase):
         ),
         (
             "NonMaxSuppression",
-            object_detection.NonMaxSuppression,
+            cv_layers.NonMaxSuppression,
             {
-                "num_classes": 5,
+                "classes": 5,
                 "bounding_box_format": "xyxy",
                 "confidence_threshold": 0.5,
                 "iou_threshold": 0.5,
@@ -200,11 +250,18 @@ class SerializationTest(tf.test.TestCase, parameterized.TestCase):
                 "max_detections_per_class": 100,
             },
         ),
+        (
+            "RandomRotation",
+            cv_layers.RandomRotation,
+            {
+                "factor": 0.5,
+            },
+        ),
     )
     def test_layer_serialization(self, layer_cls, init_args):
         layer = layer_cls(**init_args)
-        if "seed" in init_args:
-            self.assertIn("seed", layer.get_config())
+        config = layer.get_config()
+        self.assertAllInitParametersAreInConfig(layer_cls, config)
 
         model = tf.keras.models.Sequential(layer)
         model_config = model.get_config()
@@ -215,3 +272,15 @@ class SerializationTest(tf.test.TestCase, parameterized.TestCase):
         self.assertTrue(
             config_equals(layer.get_config(), reconstructed_layer.get_config())
         )
+
+    def assertAllInitParametersAreInConfig(self, layer_cls, config):
+        excluded_name = ["args", "kwargs", "*"]
+        parameter_names = {
+            v
+            for v in inspect.signature(layer_cls).parameters.keys()
+            if v not in excluded_name
+        }
+
+        intersection_with_config = {v for v in config.keys() if v in parameter_names}
+
+        self.assertSetEqual(parameter_names, intersection_with_config)
