@@ -13,8 +13,8 @@
 # limitations under the License.
 
 from keras_cv.utils.fill_utils import fill_rectangle
-from keras_cv.utils.iou import compute_ious_for_image
 from keras_cv.utils.preprocessing import blend
 from keras_cv.utils.preprocessing import parse_factor
 from keras_cv.utils.preprocessing import transform
 from keras_cv.utils.preprocessing import transform_value_range
+from keras_cv.utils.train import scale_loss_for_distribution
